@@ -109,6 +109,7 @@ static gint property_destroy_cb( GtkWidget *w, DriveData *dd)
 
 void property_show(AppletWidget *applet, gpointer data)
 {
+        static GnomeHelpMenuEntry help_entry = { NULL, "properties" };
 	DriveData *dd = data;
 	GtkWidget *frame;
 	GtkWidget *hbox;
@@ -119,6 +120,8 @@ void property_show(AppletWidget *applet, gpointer data)
 	GtkObject *delay_adj;
 	GtkWidget *button;
 
+	help_entry.name = gnome_app_id;
+
 	if(dd->propwindow)
 		{
                 gdk_window_raise(dd->propwindow->window);
@@ -197,7 +200,7 @@ void property_show(AppletWidget *applet, gpointer data)
 
 	button = gtk_check_button_new_with_label (_("Use automount friendly status test"));
         gtk_box_pack_start(GTK_BOX(frame), button, FALSE, FALSE, 5);
-        gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(button), dd->prop_autofs_friendly);
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), dd->prop_autofs_friendly);
         gtk_signal_connect (GTK_OBJECT(button),"clicked",(GtkSignalFunc) autofs_friendly_cb, dd);
         gtk_widget_show(button);
 
@@ -205,8 +208,15 @@ void property_show(AppletWidget *applet, gpointer data)
         gtk_widget_show(frame);
         gnome_property_box_append_page( GNOME_PROPERTY_BOX(dd->propwindow),frame ,label);
 
-	gtk_signal_connect( GTK_OBJECT(dd->propwindow),"apply", GTK_SIGNAL_FUNC(property_apply_cb), dd );
-	gtk_signal_connect( GTK_OBJECT(dd->propwindow),"destroy", GTK_SIGNAL_FUNC(property_destroy_cb), dd );
+	gtk_signal_connect( GTK_OBJECT(dd->propwindow), "apply",
+			    GTK_SIGNAL_FUNC(property_apply_cb), dd );
+
+	gtk_signal_connect( GTK_OBJECT(dd->propwindow), "destroy",
+			    GTK_SIGNAL_FUNC(property_destroy_cb), dd );
+
+	gtk_signal_connect( GTK_OBJECT(dd->propwindow), "help",
+			    GTK_SIGNAL_FUNC(gnome_help_pbox_display),
+			    &help_entry );
 
         gtk_widget_show_all(dd->propwindow);
 } 
