@@ -35,7 +35,24 @@ launch (GtkWidget *widget, void *data)
 {
 	GnomeDesktopEntry *item = data;
 
-	gnome_desktop_entry_launch (item);
+	if(!item->exec) {
+		GtkWidget *dlg;
+		dlg = gnome_message_box_new(_("This launch icon does not "
+					      "specify a program to run"),
+					    GNOME_MESSAGE_BOX_ERROR,
+					    _("Close"), NULL);
+		gtk_window_set_wmclass(GTK_WINDOW(dlg),
+				       "no_exec_dialog","Panel");
+		gtk_widget_show_all(dlg);
+		return;
+	}
+
+	/*UGLY HACK!*/
+	if (item->exec_length > 0
+	    && strstr(item->exec[0], "://"))
+		gnome_url_show(item->exec[0]);
+	else
+		gnome_desktop_entry_launch (item);
 }
 
 static void
@@ -199,8 +216,10 @@ create_properties_dialog(Launcher *launcher)
 	GtkWidget  *dialog;
 
 	dialog = gnome_property_box_new();
+	gtk_window_set_wmclass(GTK_WINDOW(dialog),
+			       "launcher_properties","Panel");
 	gtk_window_set_title(GTK_WINDOW(dialog), _("Launcher properties"));
-	/*gtk_window_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);*/
+	/*gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);*/
 	gtk_window_set_policy(GTK_WINDOW(dialog), FALSE, FALSE, TRUE);
 	
 	launcher->dedit =
@@ -288,7 +307,9 @@ ask_about_launcher(char *file, PanelWidget *panel, int pos)
 			     GNOME_STOCK_BUTTON_OK,
 			     GNOME_STOCK_BUTTON_CANCEL,
 			     NULL);
-	/*gtk_window_position(GTK_WINDOW(d), GTK_WIN_POS_CENTER);*/
+	gtk_window_set_wmclass(GTK_WINDOW(d),
+			       "create_launcher","Panel");
+	/*gtk_window_set_position(GTK_WINDOW(d), GTK_WIN_POS_CENTER);*/
 	gtk_window_set_policy(GTK_WINDOW(d), FALSE, FALSE, TRUE);
 	
 	notebook = gtk_notebook_new();
@@ -316,6 +337,23 @@ ask_about_launcher(char *file, PanelWidget *panel, int pos)
 	gtk_widget_show_all(d);
 }
 
+void
+load_launcher_applet_from_info(char *name, char *comment,
+			       char **exec, int execn, char *icon,
+			       PanelWidget *panel, int pos)
+{
+	GnomeDesktopEntry *dentry = g_new0(GnomeDesktopEntry,1);
+	dentry->name = g_strdup(name);
+	dentry->comment = g_strdup(comment);
+	dentry->exec_length = execn;
+	dentry->exec = g_copy_vector(exec);
+	if(icon && *icon != '/')
+		dentry->icon = gnome_pixmap_file(icon);
+	else
+		dentry->icon = g_strdup(icon);
+
+	_load_launcher_applet(NULL,dentry,panel, pos);
+}
 
 void
 load_launcher_applet(char *params, PanelWidget *panel, int pos)
