@@ -281,7 +281,7 @@ save_applet_configuration(AppletInfo *info)
 			gnome_config_set_string("id", DRAWER_ID);
 
 			i = g_slist_index(panels,
-					  DRAWER_WIDGET(drawer->drawer)->panel);
+					  BASEP_WIDGET(drawer->drawer)->panel);
 			if(i>=0)
 				gnome_config_set_int("parameters",i);
 			else
@@ -351,7 +351,8 @@ save_panel_configuration(gpointer data, gpointer user_data)
 	GString       *buf;
 	int           *num = user_data;
 	PanelData     *pd = data;
-	PanelWidget   *panel = get_def_panel_widget(pd->panel);
+	BasePWidget   *basep = BASEP_WIDGET(pd->panel);
+	PanelWidget   *panel = PANEL_WIDGET(basep->panel);
 	
 	buf = g_string_new(NULL);
 
@@ -361,6 +362,11 @@ save_panel_configuration(gpointer data, gpointer user_data)
 	gnome_config_push_prefix (buf->str);
 
 	gnome_config_set_int("type",pd->type);
+
+	gnome_config_set_bool("hidebuttons_enabled",
+			      basep->hidebuttons_enabled);
+	gnome_config_set_bool("hidebutton_pixmaps_enabled",
+			      basep->hidebutton_pixmaps_enabled);
 	
 	switch(pd->type) {
 	case SNAPPED_PANEL:
@@ -369,10 +375,6 @@ save_panel_configuration(gpointer data, gpointer user_data)
 		gnome_config_set_int("pos", snapped->pos);
 		gnome_config_set_int("mode", snapped->mode);
 		gnome_config_set_int("state", snapped->state);
-		gnome_config_set_bool("hidebuttons_enabled",
-				      snapped->hidebuttons_enabled);
-		gnome_config_set_bool("hidebutton_pixmaps_enabled",
-				      snapped->hidebutton_pixmaps_enabled);
 		break;
 		}
 	case CORNER_PANEL:
@@ -381,10 +383,6 @@ save_panel_configuration(gpointer data, gpointer user_data)
 		gnome_config_set_int("pos", corner->pos);
 		gnome_config_set_int("orient",panel->orient);
 		gnome_config_set_int("state", corner->state);
-		gnome_config_set_bool("hidebuttons_enabled",
-				      corner->hidebuttons_enabled);
-		gnome_config_set_bool("hidebutton_pixmaps_enabled",
-				      corner->hidebutton_pixmaps_enabled);
 		break;
 		}
 	case DRAWER_PANEL:
@@ -392,10 +390,6 @@ save_panel_configuration(gpointer data, gpointer user_data)
 		DrawerWidget *drawer = DRAWER_WIDGET(pd->panel);
 		gnome_config_set_int("orient",drawer->orient);
 		gnome_config_set_int("state", drawer->state);
-		gnome_config_set_bool("hidebutton_enabled",
-				      drawer->hidebutton_enabled);
-		gnome_config_set_bool("hidebutton_pixmap_enabled",
-				      drawer->hidebutton_pixmap_enabled);
 		break;
 		}
 	default:
@@ -497,6 +491,8 @@ do_session_save(GnomeClient *client,
 				      global_config.show_small_icons);
 		gnome_config_set_bool("show_dot_buttons",
 				      global_config.show_dot_buttons);
+		gnome_config_set_bool("hungry_menus",
+				      global_config.hungry_menus);
 		gnome_config_set_bool("off_panel_popups",
 				      global_config.off_panel_popups);
 		gnome_config_set_bool("prompt_for_logout",
@@ -505,6 +501,8 @@ do_session_save(GnomeClient *client,
 				      global_config.disable_animations);
 		gnome_config_set_int("applet_padding",
 				     global_config.applet_padding);
+		gnome_config_set_bool("autoraise",
+				      global_config.autoraise);
 		buf = g_string_new(NULL);
 		for(i=0;i<LAST_TILE;i++) {
 			g_string_sprintf(buf,"tiles_enabled_%d",i);
@@ -610,6 +608,10 @@ panel_really_logout(GtkWidget *w, int button, gpointer data)
 	GtkWidget **box=data;
 
 	if(button==0) {
+
+	        gnome_triggers_do("Session shutdown", NULL,
+				  "gnome", "logout", NULL);
+	  
 		if (! GNOME_CLIENT_CONNECTED (client)) {
 			panel_session_save (client, 1, GNOME_SAVE_BOTH, 1,
 					    GNOME_INTERACT_NONE, 0, NULL);
@@ -666,8 +668,10 @@ panel_quit(void)
 				     GNOME_STOCK_BUTTON_YES,
 				     GNOME_STOCK_BUTTON_NO,
 				     NULL);
+	gtk_window_set_wmclass(GTK_WINDOW(box),
+			       "logout_dialog","Panel");
 	gnome_dialog_set_default(GNOME_DIALOG(box), 0);
-	/*gtk_window_position(GTK_WINDOW(box), GTK_WIN_POS_CENTER);*/
+	/*gtk_window_set_position(GTK_WINDOW(box), GTK_WIN_POS_CENTER);*/
 	gtk_window_set_policy(GTK_WINDOW(box), FALSE, FALSE, TRUE);
 
 	gtk_signal_connect (GTK_OBJECT (box), "clicked",
@@ -680,7 +684,7 @@ panel_quit(void)
 	gtk_widget_show(but);
 	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(box)->vbox),but,
 		           FALSE, TRUE, GNOME_PAD_SMALL);
-	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(but),TRUE);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(but),TRUE);
 	gtk_signal_connect(GTK_OBJECT(but),"toggled",
 			   GTK_SIGNAL_FUNC(ask_next_time),NULL);
 
@@ -871,6 +875,8 @@ init_user_panels(void)
 		char *back_pixmap, *color;
 		GdkColor back_color = {0,0,0,1};
 		int fit_pixmap_bg;
+		int hidebuttons_enabled;
+		int hidebutton_pixmaps_enabled;
 
 		g_string_sprintf(buf,"%spanel/Panel_%d/",
 				 old_panel_cfg_path, num);
@@ -895,14 +901,17 @@ init_user_panels(void)
 		g_string_sprintf(buf,"type=%d", SNAPPED_PANEL);
 		type = gnome_config_get_int(buf->str);
 
+		hidebuttons_enabled =
+			gnome_config_get_bool("hidebuttons_enabled=TRUE");
+		hidebutton_pixmaps_enabled =
+			gnome_config_get_bool("hidebutton_pixmaps_enabled=TRUE");
+
 		switch(type) {
 		case SNAPPED_PANEL:
 			{
 				SnappedPos pos;
 				SnappedMode mode;
 				SnappedState state;
-				int hidebuttons_enabled;
-				int hidebutton_pixmaps_enabled;
 
 				g_string_sprintf(buf,"pos=%d", SNAPPED_BOTTOM);
 				pos=gnome_config_get_int(buf->str);
@@ -914,11 +923,6 @@ init_user_panels(void)
 				g_string_sprintf(buf,"state=%d", SNAPPED_SHOWN);
 				state=gnome_config_get_int(buf->str);
 
-				hidebuttons_enabled =
-					gnome_config_get_bool("hidebuttons_enabled=TRUE");
-				hidebutton_pixmaps_enabled =
-					gnome_config_get_bool("hidebutton_pixmaps_enabled=TRUE");
-
 				panel = snapped_widget_new(pos,
 							   mode,
 							   state,
@@ -934,8 +938,6 @@ init_user_panels(void)
 			{
 				DrawerState state;
 				PanelOrientType orient;
-				int hidebutton_enabled;
-				int hidebutton_pixmap_enabled;
 
 				g_string_sprintf(buf,"state=%d", DRAWER_SHOWN);
 				state=gnome_config_get_int(buf->str);
@@ -943,19 +945,14 @@ init_user_panels(void)
 				g_string_sprintf(buf,"orient=%d", ORIENT_UP);
 				orient=gnome_config_get_int(buf->str);
 
-				hidebutton_enabled =
-					gnome_config_get_bool("hidebutton_enabled=TRUE");
-				hidebutton_pixmap_enabled =
-					gnome_config_get_bool("hidebutton_pixmap_enabled=TRUE");
-
 				panel = drawer_widget_new(orient,
 							  state,
 							  back_type,
 							  back_pixmap,
 							  fit_pixmap_bg,
 							  &back_color,
-							  hidebutton_pixmap_enabled,
-							  hidebutton_enabled);
+							  hidebutton_pixmaps_enabled,
+							  hidebuttons_enabled);
 				break;
 			}
 		case CORNER_PANEL:
@@ -963,8 +960,6 @@ init_user_panels(void)
 				CornerPos pos;
 				PanelOrientation orient;
 				CornerState state;
-				int hidebuttons_enabled;
-				int hidebutton_pixmaps_enabled;
 				
 				g_string_sprintf(buf,"pos=%d", CORNER_NE);
 				pos=gnome_config_get_int(buf->str);
@@ -976,11 +971,6 @@ init_user_panels(void)
 				g_string_sprintf(buf,"state=%d", CORNER_SHOWN);
 				state=gnome_config_get_int(buf->str);
 
-				hidebuttons_enabled =
-					gnome_config_get_bool("hidebuttons_enabled=TRUE");
-				hidebutton_pixmaps_enabled =
-					gnome_config_get_bool("hidebutton_pixmaps_enabled=TRUE");
-				
 				panel = corner_widget_new(pos,
 							  orient,
 							  state,
@@ -1030,6 +1020,9 @@ load_up_globals(void)
 	global_config.show_dot_buttons =
 		gnome_config_get_bool("show_dot_buttons=FALSE");
 
+	global_config.hungry_menus =
+		gnome_config_get_bool("hungry_menus=FALSE");
+
 	global_config.off_panel_popups =
 		gnome_config_get_bool("off_panel_popups=TRUE");
 		
@@ -1062,6 +1055,8 @@ load_up_globals(void)
 
 	global_config.applet_padding=gnome_config_get_int("applet_padding=3");
 
+	global_config.autoraise = gnome_config_get_bool("autoraise=TRUE");
+
 	for(i=0;i<LAST_TILE;i++) {
 		g_string_sprintf(buf,"tiles_enabled_%d=TRUE",i);
 		global_config.tiles_enabled[i] =
